@@ -4,7 +4,9 @@ import logging
 
 import jinja2
 
-from textflow.db import db
+from textflow.model.dataset import datasets
+from textflow.model.model import models
+from textflow.service.base import database as db
 
 logger = logging.getLogger(__name__)
 
@@ -30,3 +32,17 @@ class Project(db.Model):
         if self.header_template is None:
             return None
         return jinja2.Template(self.header_template).render(document=document)
+
+    def register(self, type, name='default'):
+        """Register plugin for this project.
+
+        :param type: type of plugin
+        :param name: name of plugin
+        :return: registered object
+        """
+        if type == 'dataset':
+            return datasets.register(self.id, name=name)
+        elif type == 'model':
+            return models.register(self.id, name=name)
+        else:
+            return None
